#
# spec file for package python-scandir
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-scandir
Version:        1.10.0
Release:        4.4
Summary:        Scandir, a better directory iterator and faster oswalk
License:        BSD-3-Clause
URL:            https://github.com/benhoyt/scandir
Source:         https://files.pythonhosted.org/packages/source/s/scandir/scandir-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
``scandir()`` is a directory iteration function like ``os.listdir()``,
except that instead of returning a list of bare filenames, it yields
``DirEntry`` objects that include file type and stat information along
with the name. Using ``scandir()`` increases the speed of ``os.walk()``
by 2-20 times (depending on the platform and file system) by avoiding
unnecessary calls to ``os.stat()`` in most cases.

``scandir`` has been included in the Python 3.5 standard library as
``os.scandir()``, and the related performance improvements to
``os.walk()`` have also been included. So if you're lucky enough to be
using Python 3.5 (release date September 13, 2015) you get the benefit
immediately, otherwise just
`download this module from PyPI <https://pypi.python.org/pypi/scandir>`_,
install it with ``pip install scandir``, and then do something like
this in your code::

    # Use the built-in version of scandir/walk if possible, otherwise
    # use the scandir module version
    try:
        from os import scandir, walk
    except ImportError:
        from scandir import scandir, walk

`PEP 471 <https://www.python.org/dev/peps/pep-0471/>`_, which is the
PEP that proposes including ``scandir`` in the Python standard library,
was `accepted <https://mail.python.org/pipermail/python-dev/2014-July/135561.html>`_
in July 2014 by Victor Stinner, the BDFL-delegate for the PEP.

This ``scandir`` module is intended to work on Python 2.6+ and Python
3.2+ (and it has been tested on those versions).

%prep
%setup -q -n scandir-%{version}
rm -rf scandir.egg-info
dos2unix LICENSE.txt README.rst

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export LANG=en_US.UTF-8
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} $python test/run_tests.py

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitearch}/*

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Dec 10 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Include in SLE-12 (fate#326950, bsc#1122668, jsc#PM-1447)
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Mon Mar 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.10.0:
  * remove support for pyton 2.6 and <3.3
* Sat Mar  2 2019 John Vandenberg <jayvdb@gmail.com>
- Allow building on Python 3.5+, as it is useful for testing and it
  should exist for when packages list it as a runtime dependency, and
  it will add backports of enhancements to scandir since Python 3.5.
  bsc#1167207
* Thu Nov  1 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.9.0:
  * Mark C extension as optional for things like Jython. See #105.
  * Fix build on Python 2.7 (#107). Fix dirent struct alignment on OpenBSD (#109).
- Do not build on python 3.5+ as it is part of the base
* Mon Apr 23 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 1.7:
  * Expose scandir.DirEntry (#93).
* Fri Nov  3 2017 arun@gmx.de
- update to version 1.6:
  * Fixed #11: inode should be unsigned
  * Fixed unicode handling on PyPy due to Py_FileSystemDefaultEncoding
    always being NULL there
  * Improve tests on PyPy and Windows
  * Add Travis and Appveyor CI testing
* Sat Jul 15 2017 aloisio@gmx.com
- Converted to singlespec
* Thu Mar 30 2017 toddrme2178@gmail.com
- Initial version
